@@ -7,7 +7,8 @@ from zope.component.hooks import getSite
 def recook_resources():
     for name in ('portal_css', 'portal_javascripts'):
         registry = getToolByName(getSite(), name, None)
-        if registry is not None:
+        # Tool might not be there, or might be a dummy alias from plone.app.upgrade.
+        if registry is not None and hasattr(registry, 'cookResources'):
             registry.cookResources()
 
     # Plone 5: clear all bundles
